@@ -123,7 +123,9 @@ About::About()
 		"with this program; if not, write to the Free Software Foundation, Inc., "
 		"51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA or visit: http://www.gnu.org/";
 	set_license(license);
+#ifdef HAVE_GTK_ABOUTDIALOG_SET_WRAP_LICENSE
 	set_wrap_license(true);
+#endif
 
 	std::vector<Glib::ustring> authors;
 	authors.push_back("Original developers:");
@@ -139,10 +141,12 @@ About::About()
 	authors.push_back("Chris Moore (dooglus)");
 	authors.push_back("Chris Norman (pixelgeek)");
 	authors.push_back("Daniel Fort");
+	authors.push_back("Daniel Hornung (rubikcube)");
 	authors.push_back("David Roden (Bombe)");
 	authors.push_back("Dmitriy Pomerantsev (Atrus)");
 	authors.push_back("Douglas Lau");
 	authors.push_back("Gerald Young (Yoyobuae)");
+	authors.push_back("Gerco Ballintijn");
 	authors.push_back("IL'dar AKHmetgaleev (AkhIL)");
 	authors.push_back("Luka Pravica");
 	authors.push_back("Martin Michlmayr (tbm)");
@@ -157,6 +161,9 @@ About::About()
 	artists.push_back("Aurore D (rore)");
 	artists.push_back("Carlos López González (genete)");
 	artists.push_back("Chris Norman (pixelgeek)");
+	artists.push_back("Daniel Hornung (rubikcube)");
+	artists.push_back("Franco Iacomella (Yaco)");
+	
 	set_artists(artists);
 
 	// TRANSLATORS: change this to your name, separate multiple names with \n
@@ -172,8 +179,9 @@ About::About()
 	if(synfig_root) {
 		imagepath=synfig_root;
 		imagepath+=ETL_DIRECTORY_SEPARATOR;
-
-		imagepath+="share/pixmaps";
+		imagepath+="share";
+		imagepath+=ETL_DIRECTORY_SEPARATOR;
+		imagepath+="pixmaps";
 	}
 	imagepath+=ETL_DIRECTORY_SEPARATOR;
 
