@@ -1,11 +1,11 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file about.h
-**	\brief Header File
+**	\brief About dialog class
 **
-**	$Id: about.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id$
 **
 **	\legal
-**	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Paul Wise
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -17,10 +17,8 @@
 **	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 **	General Public License for more details.
 **	\endlegal
-**
-** === N O T E S ===========================================================
-**
-** ========================================================================= */
+*/
+/* ========================================================================= */
 
 /* === S T A R T =========================================================== */
 
@@ -29,12 +27,7 @@
 
 /* === H E A D E R S ======================================================= */
 
-//#include <gtk/gtk.h>
-#include <gtkmm/window.h>
-#include <gtkmm/tooltips.h>
-#include <gtkmm/label.h>
-#include <gtkmm/button.h>
-#include <gtkmm/progressbar.h>
+#include <gtkmm/aboutdialog.h>
 
 /* === M A C R O S ========================================================= */
 
@@ -42,39 +35,20 @@
 
 /* === C L A S S E S & S T R U C T S ======================================= */
 
-namespace synfig { class ProgressCallback; };
+# 
 
 namespace studio {
 
-class AboutProgress;
-
-class About : public Gtk::Window
+class About : public Gtk::AboutDialog
 {
-	friend class AboutProgress;
-
-	AboutProgress *cb;
-
-	Gtk::Tooltips _tooltips;
-
-	Gtk::Label *tasklabel;
-	Gtk::ProgressBar *progressbar;
-	Gtk::Button *CloseButton;
-
-	void close();
-
-	bool can_self_destruct;
-
 public:
 
-	synfig::ProgressCallback *get_callback();
-
-	void set_can_self_destruct(bool x);
-
 	About();
-	~About();
+	void close(int);
+	void on_link_clicked(Gtk::AboutDialog&, const Glib::ustring &url);
 };
-
-}
+	
+}; // END of namespace studio
 
 /* === E N D =============================================================== */
 
