@@ -2,11 +2,12 @@
 /*!	\file app.h
 **	\brief writeme
 **
-**	$Id: app.h 1802 2008-02-23 01:25:55Z dooglus $
+**	$Id: app.h 2098 2008-10-14 21:00:21Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
+**  Copyright (c) 2008 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -198,7 +199,10 @@ public:
 	static bool restrict_radius_ducks;
 
 	static synfig::String browser_command;
-
+	static synfig::String custom_filename_prefix;
+	static int preferred_x_size;
+	static int preferred_y_size;
+	static synfig::String predefined_size;
 	/*
  -- ** -- S I G N A L S -------------------------------------------------------
 	*/
@@ -331,6 +335,7 @@ public:
 	static void dialog_warning_blocking(const std::string &title, const std::string &message);
 
 	static bool dialog_entry(const std::string &title, const std::string &message,std::string &text);
+	static bool dialog_paragraph(const std::string &title, const std::string &message,std::string &text);
 
 	static bool dialog_yes_no(const std::string &title, const std::string &message);
 
