@@ -2,7 +2,7 @@
 /*!	\file canvasview.h
 **	\brief Template Header
 **
-**	$Id: canvasview.h 1757 2008-02-19 15:34:02Z dooglus $
+**	$Id: canvasview.h 2011 2008-04-10 18:43:36Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -401,9 +401,9 @@ private:
 	Gtk::Widget *create_time_bar();
 
 	void popup_param_menu_bezier(float location, synfigapp::ValueDesc value_desc)
-	{ popup_param_menu(value_desc,location); }
+	{ popup_param_menu(value_desc,location,true); }
 
-	void popup_param_menu(synfigapp::ValueDesc value_desc, float location=0);
+	void popup_param_menu(synfigapp::ValueDesc value_desc, float location=0, bool bezier=false);
 
 	void workarea_layer_selected(synfig::Layer::Handle layer);
 
@@ -595,6 +595,7 @@ public:
 
 private:
 
+	void on_select_layers();
 	void on_unselect_layers();
 
 	void on_input_device_changed(GdkDevice*);
