@@ -2,7 +2,7 @@
 /*!	\file dialog_gradient.cpp
 **	\brief Template File
 **
-**	$Id: dialog_gradient.cpp 1156 2007-11-16 04:19:10Z pabs $
+**	$Id: dialog_gradient.cpp 2108 2008-10-19 02:30:40Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -64,7 +64,7 @@ using namespace studio;
 Dialog_Gradient::Dialog_Gradient():
 	Dialog(_("Gradient Editor"),false,true),
 	dialog_settings(this,"gradient"),
-	adjustment_pos(0,0.0,1.0,0.001,0.001,0.001)
+	adjustment_pos(0,0.0,1.0,0.001,0.001,0)
 {
 	set_type_hint(Gdk::WINDOW_TYPE_HINT_DIALOG);
 	set_keep_above(false);
