@@ -2,11 +2,12 @@
 /*!	\file dialog_setup.cpp
 **	\brief Template File
 **
-**	$Id: dialog_setup.cpp 1824 2008-02-29 15:36:06Z dooglus $
+**	$Id: dialog_setup.cpp 2108 2008-10-19 02:30:40Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
+**  Copyright (c) 2008 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -74,14 +75,17 @@ Dialog_Setup::Dialog_Setup():
 	adj_gamma_r(2.2,0.1,3.0,0.025,0.025,0.025),
 	adj_gamma_g(2.2,0.1,3.0,0.025,0.025,0.025),
 	adj_gamma_b(2.2,0.1,3.0,0.025,0.025,0.025),
-	adj_recent_files(15,1,50,1,1,1),
+	adj_recent_files(15,1,50,1,1,0),
 	adj_undo_depth(100,10,5000,1,1,1),
 	toggle_use_colorspace_gamma(_("Visually Linear Color Selection")),
 #ifdef SINGLE_THREADED
 	toggle_single_threaded(_("Use Only a Single Thread")),
 #endif
-	toggle_restrict_radius_ducks(_("Restrict Real-Valued Ducks to Top Right Quadrant"))
-{
+	toggle_restrict_radius_ducks(_("Restrict Real-Valued Ducks to Top Right Quadrant")),
+	adj_pref_x_size(480,1,10000,1,10,0),
+	adj_pref_y_size(270,1,10000,1,10,0)
+	
+	{
 	// Setup the buttons
 
 	Gtk::Button *ok_button(manage(new class Gtk::Button(Gtk::StockID("gtk-ok"))));
@@ -192,11 +196,11 @@ Dialog_Setup::Dialog_Setup():
 	misc_table->attach(*recent_files_spinbutton, 1, 2, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
 
 	// Misc - use_colorspace_gamma
-	misc_table->attach(toggle_use_colorspace_gamma, 0, 2, 5, 6, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	misc_table->attach(toggle_use_colorspace_gamma, 0, 2, 7, 8, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
 
 #ifdef SINGLE_THREADED
 	// Misc - single_threaded
-	misc_table->attach(toggle_single_threaded, 0, 2, 7, 8, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	misc_table->attach(toggle_single_threaded, 0, 2, 9, 10, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
 #endif
 
 	// Misc - auto backup interval
@@ -204,12 +208,56 @@ Dialog_Setup::Dialog_Setup():
 	misc_table->attach(auto_backup_interval, 1, 2, 3, 4, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
 
 	// Misc - restrict_radius_ducks
-	misc_table->attach(toggle_restrict_radius_ducks, 0, 2, 6, 7, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	misc_table->attach(toggle_restrict_radius_ducks, 0, 2, 8, 9, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
 
 	// Misc - browser_command
 	attach_label(misc_table, _("Browser Command"), 4, xpadding, ypadding);
 	misc_table->attach(textbox_browser_command, 1, 2, 4, 5, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
 
+	// Document
+	Gtk::Table *document_table=manage(new Gtk::Table(2,4,false));
+	notebook->append_page(*document_table,_("Document"));
+
+	// Document - Preferred file name prefix
+	attach_label(document_table, _("New Document filename prefix"), 0, xpadding, ypadding);
+	document_table->attach(textbox_custom_filename_prefix, 1, 4, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	tooltips_.set_tip(textbox_custom_filename_prefix,_("File name prefix for the new created document"));
+
+	// Document - New Document X size
+	Gtk::SpinButton* pref_x_size_spinbutton(manage(new Gtk::SpinButton(adj_pref_x_size,1,0)));
+	attach_label(document_table,_("New Document X size"),1, xpadding, ypadding);
+	document_table->attach(*pref_x_size_spinbutton, 1, 2, 1, 2,Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding); 
+	tooltips_.set_tip(*pref_x_size_spinbutton,_("Width in pixels of the new created document"));
+	
+	// Document - New Document Y size
+	Gtk::SpinButton* pref_y_size_spinbutton(manage(new Gtk::SpinButton(adj_pref_y_size,1,0)));
+	attach_label(document_table,_("New Document Y size"),2, xpadding, ypadding);
+	document_table->attach(*pref_y_size_spinbutton, 1, 2, 2, 3,Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding); 
+	tooltips_.set_tip(*pref_y_size_spinbutton,_("High in pixels of the new created document"));
+
+	//Document - Template for predefined sizes of canvases.
+	size_template_combo=Gtk::manage(new Gtk::ComboBoxText());
+	Gtk::Label* label(manage(new Gtk::Label(_("Predefined Resolutions:"))));
+	label->set_alignment(Gtk::ALIGN_LEFT, Gtk::ALIGN_CENTER);
+	document_table->attach(*label, 2, 3, 1, 2, Gtk::SHRINK|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	document_table->attach(*size_template_combo,2, 3, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::SHRINK|Gtk::FILL, xpadding, ypadding);
+	size_template_combo->signal_changed().connect(sigc::mem_fun(*this,&studio::Dialog_Setup::on_size_template_combo_change));
+	size_template_combo->prepend_text(_("4096x3112 Full Aperture 4K"));
+	size_template_combo->prepend_text(_("2048x1556 Full Aperture Native 2K"));
+	size_template_combo->prepend_text(_("1920x1080 HDTV 1080p/i"));
+	size_template_combo->prepend_text(_("1280x720  HDTV 720p"));
+	size_template_combo->prepend_text(_("720x576   DVD PAL"));
+	size_template_combo->prepend_text(_("720x480   DVD NTSC"));
+	size_template_combo->prepend_text(_("720x540   Web 720x"));
+	size_template_combo->prepend_text(_("720x405   Web 720x HD"));
+	size_template_combo->prepend_text(_("640x480   Web 640x"));
+	size_template_combo->prepend_text(_("640x360   Web 640x HD"));
+	size_template_combo->prepend_text(_("480x360   Web 480x"));
+	size_template_combo->prepend_text(_("480x270   Web 480x HD"));
+	size_template_combo->prepend_text(_("360x270   Web 360x"));
+	size_template_combo->prepend_text(_("360x203   Web 360x HD"));
+	size_template_combo->prepend_text(DEFAULT_PREDEFINED_SIZE);
+
 	show_all_children();
 }
 
@@ -253,6 +301,18 @@ Dialog_Setup::on_apply_pressed()
 	// Set the browser_command textbox
 	App::browser_command=textbox_browser_command.get_text();
 
+	// Set the preferred file name prefix
+	App::custom_filename_prefix=textbox_custom_filename_prefix.get_text();
+
+	// Set the preferred new Document X dimension
+	App::preferred_x_size=int(adj_pref_x_size.get_value());
+
+	// Set the preferred new Document Y dimension
+	App::preferred_y_size=int(adj_pref_y_size.get_value());
+	
+	// Set the preferred Predefined size
+	App::predefined_size=size_template_combo->get_active_text();
+
 	App::save_settings();
 }
 
@@ -296,6 +356,24 @@ Dialog_Setup::on_red_blue_level_change()
 	gamma_pattern.queue_draw();
 }
 
+void
+Dialog_Setup::on_size_template_combo_change()
+{
+	String selection(size_template_combo->get_active_text());
+	if(selection==DEFAULT_PREDEFINED_SIZE) 
+	{
+		return;
+	}
+	String::size_type locx=selection.find_first_of("x"); // here should be some comparison with string::npos
+	String::size_type locspace=selection.find_first_of(" ");
+	String x_size(selection.substr(0,locx));
+	String y_size(selection.substr(locx+1,locspace));
+	int x=atoi(x_size.c_str());
+	int y=atoi(y_size.c_str());
+	adj_pref_x_size.set_value(x);
+	adj_pref_y_size.set_value(y);
+	return;
+}
 
 void
 Dialog_Setup::refresh()
@@ -339,6 +417,18 @@ Dialog_Setup::refresh()
 
 	// Refresh the browser_command textbox
 	textbox_browser_command.set_text(App::browser_command);
+
+	// Refresh the preferred filename prefix
+	textbox_custom_filename_prefix.set_text(App::custom_filename_prefix);
+
+	// Refresh the preferred new Document X dimension
+	adj_pref_x_size.set_value(App::preferred_x_size);
+	
+	// Refresh the preferred new Document Y dimension
+	adj_pref_y_size.set_value(App::preferred_y_size);
+	
+	// Refresh the preferred Predefined size
+	size_template_combo->set_active_text(App::predefined_size);
 }
 
 GammaPattern::GammaPattern():
