@@ -2,7 +2,7 @@
 /*!	\file duckmatic.cpp
 **	\brief Template File
 **
-**	$Id: duckmatic.cpp 1809 2008-02-24 05:16:03Z pabs $
+**	$Id: duckmatic.cpp 2022 2008-04-17 18:02:49Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -44,6 +44,9 @@
 #include <synfig/valuenode_composite.h>
 #include <synfig/valuenode_scale.h>
 #include <synfig/valuenode_bline.h>
+#include <synfig/valuenode_blinecalctangent.h>
+#include <synfig/valuenode_blinecalcvertex.h>
+#include <synfig/valuenode_blinecalcwidth.h>
 
 #include <synfig/curve_helper.h>
 
@@ -251,9 +254,10 @@ Duckmatic::is_duck_group_selectable(const etl::handle<Duck>& x)const
 		 !x->get_editable()))
 		return false;
 
-	if(x->get_value_desc().parent_is_layer_param() && type & Duck::TYPE_POSITION)
+	synfigapp::ValueDesc value_desc(x->get_value_desc());
+	if(value_desc.parent_is_layer_param() && type & Duck::TYPE_POSITION)
 	{
-		Layer::Handle layer(x->get_value_desc().get_layer());
+		Layer::Handle layer(value_desc.get_layer());
 		String layer_name(layer->get_name());
 
 		if (layer_name == "outline" || layer_name == "region" || layer_name == "plant" ||
@@ -264,6 +268,30 @@ Duckmatic::is_duck_group_selectable(const etl::handle<Duck>& x)const
 		   !layer->get_param("children_lock").get(bool()))
 			return false;
 	}
+	else if (value_desc.parent_is_value_node())
+	{
+		if (ValueNode_BLineCalcVertex::Handle::cast_dynamic(value_desc.get_value_node()))
+			return false;
+		if (value_desc.parent_is_linkable_value_node())
+		{
+			LinkableValueNode::Handle parent_value_node(value_desc.get_parent_value_node());
+			if (ValueNode_Composite::Handle::cast_dynamic(parent_value_node))
+			{
+				if (parent_value_node->get_type() == ValueBase::TYPE_BLINEPOINT &&
+					ValueNode_BLineCalcVertex::Handle::cast_dynamic(
+						parent_value_node->get_link("point")))
+					return false;
+			}
+			else if (ValueNode_BLine::Handle::cast_dynamic(parent_value_node))
+			{
+				ValueNode_Composite::Handle composite(ValueNode_Composite::Handle::cast_dynamic(
+														  value_desc.get_value_node()));
+				if (composite &&
+					ValueNode_BLineCalcVertex::Handle::cast_dynamic(composite->get_link("point")))
+					return false;
+			}
+		}
+	}
 	return true;
 }
 
@@ -278,6 +306,14 @@ Duckmatic::select_all_ducks()
 			unselect_duck(iter->second);
 }
 
+void
+Duckmatic::unselect_all_ducks()
+{
+	DuckMap::const_iterator iter;
+	for(iter=duck_map.begin();iter!=duck_map.end();++iter)
+		unselect_duck(iter->second);
+}
+
 void
 Duckmatic::toggle_select_ducks_in_box(const synfig::Vector& tl,const synfig::Vector& br)
 {
@@ -505,21 +541,102 @@ DuckDrag_Translate::duck_drag(Duckmatic* duckmatic, const synfig::Vector& vector
 
 	synfig::Vector vect(duckmatic->snap_point_to_grid(vector)-drag_offset_);
 	int i;
+	Time time(duckmatic->get_time());
 
-	for(i=0,iter=selected_ducks.begin();iter!=selected_ducks.end();++iter,i++)
+	// drag the vertex and position ducks first
+	for (i=0,iter=selected_ducks.begin(); iter!=selected_ducks.end(); ++iter,i++)
 	{
-		if((*iter)->get_type()!=Duck::TYPE_VERTEX &&
-		   (*iter)->get_type()!=Duck::TYPE_POSITION)
-			continue;
-		(*iter)->set_trans_point(positions[i]+vect);
+		etl::handle<Duck> duck(*iter);
+		if(duck->get_type() == Duck::TYPE_VERTEX || duck->get_type() == Duck::TYPE_POSITION)
+		{
+			duck->set_trans_point(positions[i]+vect);
+
+			ValueNode_BLineCalcVertex::Handle bline_vertex;
+			ValueNode_Composite::Handle composite;
+
+			if ((bline_vertex = ValueNode_BLineCalcVertex::Handle::cast_dynamic(duck->get_value_desc().get_value_node())) ||
+				((composite = ValueNode_Composite::Handle::cast_dynamic(duck->get_value_desc().get_value_node())) &&
+				 composite->get_type() == ValueBase::TYPE_BLINEPOINT &&
+				 (bline_vertex = ValueNode_BLineCalcVertex::Handle::cast_dynamic(composite->get_link("point")))))
+			{
+				synfig::Point closest_point = duck->get_point();
+				synfig::Real radius = 0.0;
+				ValueNode_BLine::Handle bline = ValueNode_BLine::Handle::cast_dynamic(bline_vertex->get_link(bline_vertex->get_link_index_from_name("bline")));
+				synfig::find_closest_point(
+					(*bline)(time),
+					duck->get_point(),
+					radius,
+					bline->get_loop(),
+					&closest_point);
+				duck->set_point(closest_point);
+			}
+		}
 	}
-	for(i=0,iter=selected_ducks.begin();iter!=selected_ducks.end();++iter,i++)
+
+	// then drag the others
+	for (i=0,iter=selected_ducks.begin(); iter!=selected_ducks.end(); ++iter,i++)
+		if ((*iter)->get_type() != Duck::TYPE_VERTEX && (*iter)->get_type() != Duck::TYPE_POSITION)
+			(*iter)->set_trans_point(positions[i]+vect);
+
+	// then patch up the tangents for the vertices we've moved
+	DuckList duck_list(duckmatic->get_duck_list());
+	for (iter=selected_ducks.begin(); iter!=selected_ducks.end(); ++iter)
 	{
-		if((*iter)->get_type()==Duck::TYPE_VERTEX ||
-		   (*iter)->get_type()==Duck::TYPE_POSITION)
-			continue;
-		(*iter)->set_trans_point(positions[i]+vect);
+		etl::handle<Duck> duck(*iter);
+		if (duck->get_type() == Duck::TYPE_VERTEX || duck->get_type() == Duck::TYPE_POSITION)
+		{
+			ValueNode_BLineCalcVertex::Handle bline_vertex;
+			ValueNode_Composite::Handle composite;
+
+			if ((bline_vertex = ValueNode_BLineCalcVertex::Handle::cast_dynamic(duck->get_value_desc().get_value_node())) ||
+				((composite = ValueNode_Composite::Handle::cast_dynamic(duck->get_value_desc().get_value_node())) &&
+				 composite->get_type() == ValueBase::TYPE_BLINEPOINT &&
+				 (bline_vertex = ValueNode_BLineCalcVertex::Handle::cast_dynamic(composite->get_link("point")))))
+			{
+				synfig::Real radius = 0.0;
+				ValueNode_BLine::Handle bline(ValueNode_BLine::Handle::cast_dynamic(bline_vertex->get_link(bline_vertex->get_link_index_from_name("bline"))));
+				Real amount = synfig::find_closest_point((*bline)(time), duck->get_point(), radius, bline->get_loop());
+
+				int vertex_amount_index(bline_vertex->get_link_index_from_name("amount"));
+				ValueNode::Handle vertex_amount_value_node(bline_vertex->get_link(vertex_amount_index));
+
+				DuckList::iterator iter;
+				for (iter=duck_list.begin(); iter!=duck_list.end(); iter++)
+				{
+					ValueNode::Handle duck_value_node((*iter)->get_value_desc().get_value_node());
+					if (ValueNode_BLineCalcTangent::Handle bline_tangent = ValueNode_BLineCalcTangent::Handle::cast_dynamic(duck_value_node))
+					{
+						if (bline_tangent->get_link(bline_tangent->get_link_index_from_name("amount")) == vertex_amount_value_node)
+						{
+							switch (bline_tangent->get_type())
+							{
+							case ValueBase::TYPE_ANGLE:
+							{
+								Angle angle((*bline_tangent)(time, amount).get(Angle()));
+								(*iter)->set_point(Point(Angle::cos(angle).get(), Angle::sin(angle).get()));
+								break;
+							}
+							case ValueBase::TYPE_REAL:
+								(*iter)->set_point(Point((*bline_tangent)(time, amount).get(Real()), 0));
+								break;
+							case ValueBase::TYPE_VECTOR:
+								(*iter)->set_point((*bline_tangent)(time, amount).get(Vector()));
+								break;
+							default:
+								break;
+							}
+						}
+					}
+					else if (ValueNode_BLineCalcWidth::Handle bline_width = ValueNode_BLineCalcWidth::Handle::cast_dynamic(duck_value_node))
+					{
+						if (bline_width->get_link(bline_width->get_link_index_from_name("amount")) == vertex_amount_value_node)
+							(*iter)->set_point(Point((*bline_width)(time, amount).get(Real()), 0));
+					}
+				}
+			}
+		}
 	}
+
 	last_translate_=vect;
 }
 
@@ -1064,9 +1181,11 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 			duck->signal_user_click(2).connect(
 				sigc::bind(
 					sigc::bind(
-						sigc::mem_fun(
-							*canvas_view,
-							&studio::CanvasView::popup_param_menu),
+						sigc::bind(
+							sigc::mem_fun(
+								*canvas_view,
+								&studio::CanvasView::popup_param_menu),
+							false),
 						0.0f),
 					value_desc));
 
@@ -1134,9 +1253,11 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 			duck->signal_user_click(2).connect(
 				sigc::bind(
 					sigc::bind(
-						sigc::mem_fun(
-							*canvas_view,
-							&studio::CanvasView::popup_param_menu),
+						sigc::bind(
+							sigc::mem_fun(
+								*canvas_view,
+								&studio::CanvasView::popup_param_menu),
+							false),
 						0.0f),
 					value_desc));
 			duck->set_guid(calc_duck_guid(value_desc,transform_stack)^synfig::GUID::hasher(multiple));
@@ -1225,9 +1346,11 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 			duck->signal_user_click(2).connect(
 				sigc::bind(
 					sigc::bind(
-						sigc::mem_fun(
-							*canvas_view,
-							&studio::CanvasView::popup_param_menu),
+						sigc::bind(
+							sigc::mem_fun(
+								*canvas_view,
+								&studio::CanvasView::popup_param_menu),
+							false),
 						1.0f),
 					value_desc));
 			duck->set_guid(calc_duck_guid(value_desc,transform_stack)^synfig::GUID::hasher(multiple));
@@ -1236,7 +1359,7 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 			return true;
 		}
 		break;
-/*	case ValueBase::TYPE_SEGMENT:
+	case ValueBase::TYPE_SEGMENT:
 		{
 			etl::handle<Bezier> bezier(new Bezier());
 			ValueNode_Composite::Handle value_node;
@@ -1291,12 +1414,12 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 					name=guid_string(value_desc);
 				}
 
-				duck_p=new class Duck(segment.p1);
+				duck_p=new Duck(segment.p1);
 				duck_p->set_name(name+".P1");
 				duck_p->set_type(Duck::TYPE_VERTEX);
 				add_duck(duck_p);
 
-				duck_c=new class Duck(segment.t1);
+				duck_c=new Duck(segment.t1);
 				duck_c->set_name(name+".T1");
 				duck_c->set_type(Duck::TYPE_TANGENT);
 				add_duck(duck_c);
@@ -1307,12 +1430,12 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 				bezier->p1=duck_p;
 				bezier->c1=duck_c;
 
-				duck_p=new class Duck(segment.p2);
+				duck_p=new Duck(segment.p2);
 				duck_p->set_name(name+".P2");
 				duck_p->set_type(Duck::TYPE_VERTEX);
 				add_duck(duck_p);
 
-				duck_c=new class Duck(segment.t2);
+				duck_c=new Duck(segment.t2);
 				duck_c->set_type(Duck::TYPE_TANGENT);
 				duck_c->set_name(name+".T2");
 				add_duck(duck_c);
@@ -1328,7 +1451,6 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 			return true;
 		}
 		break;
-*/
 	case ValueBase::TYPE_BLINEPOINT:
 	{
 
@@ -1423,9 +1545,11 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 						duck->signal_user_click(2).connect(
 							sigc::bind(
 								sigc::bind(
-									sigc::mem_fun(
-										*canvas_view,
-										&studio::CanvasView::popup_param_menu),
+									sigc::bind(
+										sigc::mem_fun(
+											*canvas_view,
+											&studio::CanvasView::popup_param_menu),
+										false),
 									1.0f),
 								synfigapp::ValueDesc(value_node,i)));
 						duck->set_value_desc(synfigapp::ValueDesc(value_node,i));
@@ -1551,9 +1675,11 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 					duck->signal_user_click(2).connect(
 						sigc::bind(
 							sigc::bind(
-								sigc::mem_fun(
-									*canvas_view,
-									&studio::CanvasView::popup_param_menu),
+								sigc::bind(
+									sigc::mem_fun(
+										*canvas_view,
+										&studio::CanvasView::popup_param_menu),
+									false),
 								1.0f),
 							synfigapp::ValueDesc(value_node,i)));
 					duck->set_value_desc(synfigapp::ValueDesc(value_node,i));
@@ -1606,9 +1732,11 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 					duck->signal_user_click(2).connect(
 						sigc::bind(
 							sigc::bind(
-								sigc::mem_fun(
-									*canvas_view,
-									&studio::CanvasView::popup_param_menu),
+								sigc::bind(
+									sigc::mem_fun(
+										*canvas_view,
+										&studio::CanvasView::popup_param_menu),
+									false),
 								1.0f),
 							synfigapp::ValueDesc(value_node,i)));
 					duck->set_value_desc(synfigapp::ValueDesc(value_node,i));
@@ -1672,9 +1800,11 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 				duck->signal_user_click(2).connect(
 					sigc::bind(
 						sigc::bind(
-							sigc::mem_fun(
-								*canvas_view,
-								&studio::CanvasView::popup_param_menu),
+							sigc::bind(
+								sigc::mem_fun(
+									*canvas_view,
+									&studio::CanvasView::popup_param_menu),
+								false),
 							1.0f),
 						synfigapp::ValueDesc(value_node,first)));
 				duck->set_value_desc(synfigapp::ValueDesc(value_node,first));
@@ -1767,7 +1897,7 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 							synfigapp::ValueDesc(value_node,first)));
 				}
 			}
-			/*else if(value_node->get_contained_type()==ValueBase::TYPE_SEGMENT)
+			else if(value_node->get_contained_type()==ValueBase::TYPE_SEGMENT)
 			{
 				for(i=0;i<value_node->link_count();i++)
 				{
@@ -1777,7 +1907,6 @@ Duckmatic::add_to_ducks(const synfigapp::ValueDesc& value_desc,etl::handle<Canva
 						return false;
 				}
 			}
-			*/
 			else
 				return false;
 		}
