@@ -2,10 +2,11 @@
 /*!	\file historytreestore.h
 **	\brief Template Header
 **
-**	$Id: historytreestore.h 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: historytreestore.h 1749 2008-02-18 18:15:49Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -100,6 +101,22 @@ private:
 
 private:
 
+	/*
+ -- ** -- P R I V A T E   D A T A ---------------------------------------------
+	*/
+
+private:
+
+	sigc::signal<void> signal_undo_tree_changed_;
+
+	/*
+ -- ** -- S I G N A L   I N T E R F A C E S -----------------------------------
+	*/
+
+public:
+
+	sigc::signal<void>& signal_undo_tree_changed() { return signal_undo_tree_changed_; }
+
 	/*
  -- ** -- S I G N A L   T E R M I N A L S -------------------------------------
 	*/
@@ -136,6 +153,8 @@ public:
 
 	void insert_action(Gtk::TreeRow row,etl::handle<synfigapp::Action::Undoable> action, bool is_active=true, bool is_undo=true, bool is_redo=false);
 
+	static bool search_func(const Glib::RefPtr<TreeModel>&,int,const Glib::ustring&,const TreeModel::iterator&);
+
 	/*
  -- ** -- P R O T E C T E D   M E T H O D S -----------------------------------
 	*/
