@@ -2,11 +2,12 @@
 /*!	\file gtkmm/instance.cpp
 **	\brief writeme
 **
-**	$Id: instance.cpp 1802 2008-02-23 01:25:55Z dooglus $
+**	$Id: instance.cpp 2098 2008-10-14 21:00:21Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
+**  Copyright (c) 2008 Carlos López
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -53,6 +54,7 @@
 #include "widget_waypointmodel.h"
 #include <gtkmm/actiongroup.h>
 #include "iconcontroller.h"
+#include "workarea.h"
 #include <sys/stat.h>
 #include <errno.h>
 #include <ETL/stringf>
@@ -228,8 +230,8 @@ studio::Instance::save()
 		App::add_recent_file(etl::handle<Instance>(this));
 		return STATUS_OK;
 	}
-
-	App::dialog_error_blocking("Save - Error","Unable to save to '" + get_file_name() + "'");
+	string msg(strprintf(_("Unable to save to '%s'"), get_file_name().c_str()));
+	App::dialog_error_blocking(_("Save - Error"), msg.c_str());
 	return STATUS_ERROR;
 }
 
@@ -239,7 +241,7 @@ studio::Instance::save()
 bool
 studio::Instance::has_real_filename()
 {
-	return get_file_name().find(DEFAULT_FILENAME_PREFIX) != 0;
+	return get_file_name().find(App::custom_filename_prefix.c_str()) != 0;
 }
 
 bool
@@ -259,12 +261,11 @@ studio::Instance::dialog_save_as()
 				Layer::Handle parent_layer(dynamic_cast<Layer*>(node));
 				if(parent_layer && parent_layer->get_canvas()->get_root()!=get_canvas())
 				{
-					App::dialog_error_blocking("SaveAs - Error",
-						"There is currently a bug when using \"SaveAs\"\n"
+					string msg(strprintf(_("There is currently a bug when using \"SaveAs\"\n"
 						"on a composition that is being referenced by other\n"
 						"files that are currently open. Close these\n"
-						"other files first before trying to use \"SaveAs\"."
-					);
+						"other files first before trying to use \"SaveAs\".")));
+					App::dialog_error_blocking(_("SaveAs - Error"), msg.c_str());
 
 					return false;
 				}
@@ -314,17 +315,16 @@ studio::Instance::dialog_save_as()
 			if (stat_return == -1 && errno != ENOENT)
 			{
 				perror(filename.c_str());
-				App::dialog_error_blocking("SaveAs - Error","Unable to check whether '" + filename + "' exists.");
+				string msg(strprintf(_("Unable to check whether '%s' exists."), filename.c_str()));
+				App::dialog_error_blocking(_("SaveAs - Error"),msg.c_str());
 				continue;
 			}
 
 			// if the file exists and the user doesn't want to overwrite it, keep prompting for a filename
+			string msg(strprintf(_("A file named '%s' already exists.\n\n"
+									"Do you want to replace it with the file you are saving?"), filename.c_str()));
 			if ((stat_return == 0) &&
-				!App::dialog_yes_no("File exists",
-									"A file named '" +
-									filename +
-									"' already exists.\n\n"
-									"Do you want to replace it with the file you are saving?"))
+				!App::dialog_yes_no(_("File exists"),msg.c_str()))
 				continue;
 		}
 
@@ -333,8 +333,8 @@ studio::Instance::dialog_save_as()
 			synfig::set_file_version(ReleaseVersion(RELEASE_VERSION_END-1));
 			return true;
 		}
-
-		App::dialog_error_blocking("SaveAs - Error","Unable to save to '" + filename + "'");
+		string msg(strprintf(_("Unable to save to '%s'"), filename.c_str()));
+		App::dialog_error_blocking(_("SaveAs - Error"),msg.c_str());
 	}
 
 	return false;
@@ -1002,7 +1002,7 @@ Instance::process_action(synfig::String name, synfigapp::Action::ParamList param
 }
 
 void
-Instance::make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas, synfigapp::ValueDesc value_desc, float location)
+Instance::make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas, synfigapp::ValueDesc value_desc, float location, bool bezier)
 {
 	Gtk::Menu& parammenu(*menu);
 
@@ -1065,10 +1065,24 @@ Instance::make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas, synfiga
 		parammenu.items().push_back(Gtk::Menu_Helpers::StockMenuElem(Gtk::Stock::CONVERT,*convert_menu));
 	}
 
+	synfigapp::Action::Category categories = synfigapp::Action::CATEGORY_VALUEDESC|synfigapp::Action::CATEGORY_VALUENODE;
+	if (bezier)
+	{
+		categories = categories|synfigapp::Action::CATEGORY_BEZIER;
+
+		const DuckList selected_ducks(find_canvas_view(canvas)->get_work_area()->get_selected_ducks());
+		for(DuckList::const_iterator iter=selected_ducks.begin();iter!=selected_ducks.end();++iter)
+		{
+			synfigapp::ValueDesc value_desc((*iter)->get_value_desc());
+			if(value_desc.is_valid())
+				param_list.add("selected_value_desc",value_desc);
+		}
+	}
+
 	if(param_list2.empty())
-		add_actions_to_menu(&parammenu, param_list,synfigapp::Action::CATEGORY_VALUEDESC|synfigapp::Action::CATEGORY_VALUENODE);
+		add_actions_to_menu(&parammenu, param_list,categories);
 	else
-		add_actions_to_menu(&parammenu, param_list2,param_list,synfigapp::Action::CATEGORY_VALUEDESC|synfigapp::Action::CATEGORY_VALUENODE);
+		add_actions_to_menu(&parammenu, param_list2,param_list,categories);
 
 	if(value_desc.get_value_type()==ValueBase::TYPE_BLINEPOINT && value_desc.is_value_node() && ValueNode_Composite::Handle::cast_dynamic(value_desc.get_value_node()))
 	{
