@@ -2,7 +2,7 @@
 /*!	\file gtkmm/instance.h
 **	\brief writeme
 **
-**	$Id: instance.h 1782 2008-02-20 02:06:58Z dooglus $
+**	$Id: instance.h 1871 2008-03-06 21:28:25Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -216,7 +216,7 @@ public:
 
 	void process_action(synfig::String name, synfigapp::Action::ParamList param_list);
 
-	void make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas, synfigapp::ValueDesc value_desc, float location=0.5f);
+	void make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas, synfigapp::ValueDesc value_desc, float location=0.5f, bool bezier=false);
 
 	void make_param_menu(Gtk::Menu *menu,synfig::Canvas::Handle canvas,const std::list<synfigapp::ValueDesc>& value_desc_list);
 
