@@ -2,7 +2,7 @@
 /*!	\file ipc.cpp
 **	\brief Template File
 **
-**	$Id: ipc.cpp 1490 2008-01-25 17:57:53Z dooglus $
+**	$Id: ipc.cpp 1967 2008-04-06 19:26:59Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -227,8 +227,6 @@ IPC::fifo_path()
 bool
 IPC::fifo_activity(Glib::IOCondition cond)
 {
-	synfig::info(__FILE__":%d: fifo activity",__LINE__);
-
 	if(cond&(Glib::IO_ERR|Glib::IO_HUP|Glib::IO_NVAL))
 	{
 		if(cond&(Glib::IO_ERR))
@@ -239,7 +237,6 @@ IPC::fifo_activity(Glib::IOCondition cond)
 			synfig::error("IPC::fifo_activity(): IO_NVAL");
 		return false;
 	}
-	synfig::info(__FILE__":%d: fifo activity",__LINE__);
 
 	String command;
 	{
@@ -252,6 +249,7 @@ IPC::fifo_activity(Glib::IOCondition cond)
 		} while(tmp!='\n');
 	}
 
+	synfig::info("%s:%d: fifo activity: '%s'", __FILE__, __LINE__, command.c_str());
 	process_command(command);
 	return true;
 }
