@@ -2,7 +2,7 @@
 /*!	\file keymapsettings.cpp
 **	\brief Contains Info for Key Map settings
 **
-**	$Id: keymapsettings.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: keymapsettings.cpp 1205 2007-12-17 09:43:41Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -35,6 +35,8 @@
 #include <gtkmm/accelmap.h>
 #include <gtk/gtkaccelmap.h>
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -78,7 +80,7 @@ bool KeyMapSettings::set_key(const char *path, guint key, Gdk::ModifierType mod,
 	}
 }
 
-bool KeyMapSettings::get_key(const char *path, AccelKey *key)
+bool KeyMapSettings::get_key(const char *path, Gtk::AccelKey *key)
 {
 	GtkAccelKey	ac;
 	if(gtk_accel_map_lookup_entry(path,&ac))
