@@ -2,7 +2,7 @@
 /*!	\file gtkmm/main.cpp
 **	\brief Synfig Studio Entrypoint
 **
-**	$Id: main.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id: main.cpp 1966 2008-04-06 19:26:41Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -73,19 +73,15 @@ int main(int argc, char **argv)
 			cout << "   " << _("synfig studio is already running") << endl << endl;
 			cout << "   " << _("the existing process will be used") << endl << endl;;
 
-			fprintf(file.get(),"F\n");
-
 			// Hey, another copy of us is open!
 			// don't bother opening us, just go ahead and
 			// tell the other copy to load it all up
-			if(argc>=1)
-			{
-				for(;argc>=1;(argc)--)
-					if((argv)[argc] && (argv)[argc][0]!='-')
-					{
-						fprintf(file.get(),"O %s\n",etl::absolute_path((argv)[argc]).c_str());
-					}
-			}
+			if (argc>1)
+				fprintf(file.get(),"F\n");
+
+			while(--argc)
+				if((argv)[argc] && (argv)[argc][0]!='-')
+					fprintf(file.get(),"O %s\n",etl::absolute_path((argv)[argc]).c_str());
 
 			fprintf(file.get(),"F\n");
 
