@@ -2,7 +2,7 @@
 /*!	\file gtkmm/renddesc.cpp
 **	\brief Template File
 **
-**	$Id: renddesc.cpp 848 2007-10-06 02:25:36Z dooglus $
+**	$Id: renddesc.cpp 1655 2008-02-10 15:41:26Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -39,6 +39,8 @@
 #include <synfig/general.h>
 //#include <gtkmm/separator.h>
 
+#include "general.h"
+
 #endif
 
 /* === U S I N G =========================================================== */
@@ -58,10 +60,6 @@ using namespace studio;
 #define SYNFIG_MAX_PIXEL_HEIGHT	(~(1<<31))
 #endif
 
-#if ! defined(_)
-#define _(x)	(x)
-#endif
-
 #ifndef DPM2DPI
 #define DPM2DPI(x)	((x)/39.3700787402)
 #define DPI2DPM(x)	((x)*39.3700787402)
@@ -403,7 +401,6 @@ Widget_RendDesc::create_widgets()
 	toggle_im_height->set_alignment(0, 0.5);
 	toggle_im_span=manage(new Gtk::CheckButton(_("Image _Span"), true));
 	toggle_im_span->set_alignment(0, 0.5);
-	time_frame=manage(new Gtk::Frame(_("Time")));
 }
 
 void
@@ -532,9 +529,9 @@ Widget_RendDesc::create_time_tab()
 	Gtk::VBox *panelBox = manage(new Gtk::VBox(false, 12)); // for future widgets
 	paddedPanel->add(*panelBox);
 
-	Gtk::Frame *time_frame = manage(new Gtk::Frame("Time Settings"));
+	time_frame = manage(new Gtk::Frame(_("Time Settings")));
 	time_frame->set_shadow_type(Gtk::SHADOW_NONE);
-	((Gtk::Label *) time_frame->get_label_widget())->set_markup("<b>Time Settings</b>");
+	((Gtk::Label *) time_frame->get_label_widget())->set_markup(_("<b>Time Settings</b>"));
 	panelBox->pack_start(*time_frame, false, false, 0);
 
 	Gtk::Alignment *timeFramePadding = manage(new Gtk::Alignment(0, 0, 1, 1));
