@@ -2,11 +2,12 @@
 /*!	\file renderer_ducks.cpp
 **	\brief Template File
 **
-**	$Id: renderer_ducks.cpp 1814 2008-02-24 20:50:44Z dooglus $
+**	$Id: renderer_ducks.cpp 2098 2008-10-14 21:00:21Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2007, 2008 Chris Moore
+**  Copyright (c) 2008 Gerald Young
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -249,7 +250,9 @@ Renderer_Ducks::render_vfunc(
 		if(get_work_area()->get_selected_value_node())
 		{
 			synfigapp::ValueDesc value_desc((*iter)->get_value_desc());
-			if(value_desc.is_valid() && value_desc.is_value_node() && get_work_area()->get_selected_value_node()==value_desc.get_value_node())
+			if (value_desc.is_valid() &&
+				((value_desc.is_value_node()		&& get_work_area()->get_selected_value_node() == value_desc.get_value_node()) ||
+				 (value_desc.parent_is_value_node()	&& get_work_area()->get_selected_value_node() == value_desc.get_parent_value_node())))
 			{
 				gc->set_function(Gdk::COPY);
 				gc->set_rgb_fg_color(DUCK_COLOR_SELECTED);
