@@ -2,7 +2,7 @@
 /*!	\file state_bline.cpp
 **	\brief Template File
 **
-**	$Id: state_bline.cpp 1809 2008-02-24 05:16:03Z pabs $
+**	$Id: state_bline.cpp 2014 2008-04-11 14:01:00Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -120,7 +120,7 @@ class studio::StateBLine_Context : public sigc::trackable
 	Gtk::CheckButton checkbutton_layer_outline;
 	Gtk::CheckButton checkbutton_layer_curve_gradient;
 	Gtk::CheckButton checkbutton_layer_plant;
-	Gtk::CheckButton checkbutton_layer_link_offsets;
+	Gtk::CheckButton checkbutton_layer_link_origins;
 	Gtk::CheckButton checkbutton_auto_export;
 	Gtk::Button button_make;
 	Gtk::Button button_clear;
@@ -161,8 +161,8 @@ public:
 	bool get_layer_plant_flag()const { return checkbutton_layer_plant.get_active(); }
 	void set_layer_plant_flag(bool x) { return checkbutton_layer_plant.set_active(x); }
 
-	bool get_layer_link_offsets_flag()const { return checkbutton_layer_link_offsets.get_active(); }
-	void set_layer_link_offsets_flag(bool x) { return checkbutton_layer_link_offsets.set_active(x); }
+	bool get_layer_link_origins_flag()const { return checkbutton_layer_link_origins.get_active(); }
+	void set_layer_link_origins_flag(bool x) { return checkbutton_layer_link_origins.set_active(x); }
 
 	Real get_feather() const { return adj_feather.get_value(); }
 	void set_feather(Real x) { return adj_feather.set_value(x); }
@@ -217,15 +217,15 @@ public:
 StateBLine::StateBLine():
 	Smach::state<StateBLine_Context>("bline")
 {
-	insert(event_def(EVENT_LAYER_SELECTION_CHANGED,&StateBLine_Context::event_layer_selection_changed_handler));
-	insert(event_def(EVENT_STOP,&StateBLine_Context::event_stop_handler));
-	insert(event_def(EVENT_REFRESH,&StateBLine_Context::event_refresh_handler));
-	insert(event_def(EVENT_REFRESH_DUCKS,&StateBLine_Context::event_hijack));
-	insert(event_def(EVENT_WORKAREA_MOUSE_BUTTON_DOWN,&StateBLine_Context::event_mouse_click_handler));
-	insert(event_def(EVENT_WORKAREA_MOUSE_BUTTON_UP,&StateBLine_Context::event_mouse_release_handler));
-	insert(event_def(EVENT_WORKAREA_MOUSE_MOTION,&StateBLine_Context::event_mouse_motion_handler));
-	insert(event_def(EVENT_WORKAREA_MOUSE_BUTTON_DRAG,&StateBLine_Context::event_mouse_motion_handler));
-	insert(event_def(EVENT_REFRESH_TOOL_OPTIONS,&StateBLine_Context::event_refresh_tool_options));
+	insert(event_def(EVENT_LAYER_SELECTION_CHANGED,		&StateBLine_Context::event_layer_selection_changed_handler));
+	insert(event_def(EVENT_STOP,						&StateBLine_Context::event_stop_handler));
+	insert(event_def(EVENT_REFRESH,						&StateBLine_Context::event_refresh_handler));
+	insert(event_def(EVENT_REFRESH_DUCKS,				&StateBLine_Context::event_hijack));
+	insert(event_def(EVENT_WORKAREA_MOUSE_BUTTON_DOWN,	&StateBLine_Context::event_mouse_click_handler));
+	insert(event_def(EVENT_WORKAREA_MOUSE_BUTTON_UP,	&StateBLine_Context::event_mouse_release_handler));
+	insert(event_def(EVENT_WORKAREA_MOUSE_MOTION,		&StateBLine_Context::event_mouse_motion_handler));
+	insert(event_def(EVENT_WORKAREA_MOUSE_BUTTON_DRAG,	&StateBLine_Context::event_mouse_motion_handler));
+	insert(event_def(EVENT_REFRESH_TOOL_OPTIONS,		&StateBLine_Context::event_refresh_tool_options));
 }
 
 StateBLine::~StateBLine()
@@ -257,10 +257,10 @@ StateBLine_Context::load_settings()
 	else
 		set_layer_plant_flag(false);
 
-	if(settings.get_value("bline.layer_link_offsets",value) && value=="0")
-		set_layer_link_offsets_flag(false);
+	if(settings.get_value("bline.layer_link_origins",value) && value=="0")
+		set_layer_link_origins_flag(false);
 	else
-		set_layer_link_offsets_flag(true);
+		set_layer_link_origins_flag(true);
 
 	if(settings.get_value("bline.auto_export",value) && value=="1")
 		set_auto_export_flag(true);
@@ -289,7 +289,7 @@ StateBLine_Context::save_settings()
 	settings.set_value("bline.layer_region",get_layer_region_flag()?"1":"0");
 	settings.set_value("bline.layer_curve_gradient",get_layer_curve_gradient_flag()?"1":"0");
 	settings.set_value("bline.layer_plant",get_layer_plant_flag()?"1":"0");
-	settings.set_value("bline.layer_link_offsets",get_layer_link_offsets_flag()?"1":"0");
+	settings.set_value("bline.layer_link_origins",get_layer_link_origins_flag()?"1":"0");
 	settings.set_value("bline.auto_export",get_auto_export_flag()?"1":"0");
 	settings.set_value("bline.id",get_id().c_str());
 	settings.set_value("bline.feather",strprintf("%f",get_feather()));
@@ -358,11 +358,11 @@ StateBLine_Context::StateBLine_Context(CanvasView* canvas_view):
 	duckmatic_push(get_work_area()),
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
 	entry_id(),
-	checkbutton_layer_region(_("Fill")),
-	checkbutton_layer_outline(_("Outline")),
-	checkbutton_layer_curve_gradient(_("Gradient")),
-	checkbutton_layer_plant(_("Plant")),
-	checkbutton_layer_link_offsets(_("Link Offsets")),
+	checkbutton_layer_region(_("Create Region BLine")),
+	checkbutton_layer_outline(_("Create Outline BLine")),
+	checkbutton_layer_curve_gradient(_("Create Curve Gradient BLine")),
+	checkbutton_layer_plant(_("Create Plant BLine")),
+	checkbutton_layer_link_origins(_("Link Origins")),
 	checkbutton_auto_export(_("Auto Export")),
 	button_make(_("Make")),
 	button_clear(_("Clear")),
@@ -374,16 +374,16 @@ StateBLine_Context::StateBLine_Context(CanvasView* canvas_view):
 	load_settings();
 
 	// Set up the tool options dialog
-	//options_table.attach(*manage(new Gtk::Label(_("BLine Tool"))), 0, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(entry_id,								0, 2,  1,  2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_outline,				0, 2,  2,  3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_region,				0, 2,  3,  4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_plant,				0, 2,  4,  5, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_curve_gradient,		0, 2,  5,  6, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_layer_link_offsets,		0, 2,  6,  7, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(checkbutton_auto_export,				0, 2,  7,  8, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(*manage(new Gtk::Label(_("Feather"))), 0, 1, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_feather,							1, 2, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(*manage(new Gtk::Label(_("BLine Tool"))),	0, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(entry_id,									0, 2,  1,  2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_outline,					0, 2,  2,  3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_region,					0, 2,  3,  4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_plant,					0, 2,  4,  5, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_curve_gradient,			0, 2,  5,  6, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_layer_link_origins,			0, 2,  6,  7, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(checkbutton_auto_export,					0, 2,  7,  8, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(*manage(new Gtk::Label(_("Feather"))), 	0, 1, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_feather,								1, 2, 10, 11, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 	//options_table.attach(button_make, 0, 2, 5, 6, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 	//button_make.signal_pressed().connect(sigc::mem_fun(*this,&StateBLine_Context::run));
 	options_table.show_all();
@@ -569,8 +569,8 @@ StateBLine_Context::run_()
 		ValueNode_BLine::Handle value_node_bline(ValueNode_BLine::create(new_list));
 		assert(value_node_bline);
 
-		ValueNode_Const::Handle value_node_offset(ValueNode_Const::create(Vector()));
-		assert(value_node_offset);
+		ValueNode_Const::Handle value_node_origin(ValueNode_Const::create(Vector()));
+		assert(value_node_origin);
 
 		// Set the looping flag
 		value_node_bline->set_loop(loop_);
@@ -606,6 +606,11 @@ StateBLine_Context::run_()
 		value_node_bline->set_member_canvas(canvas);
 
 		synfigapp::SelectionManager::LayerList layer_selection;
+		if (!getenv("SYNFIG_TOOLS_CLEAR_SELECTION"))
+			layer_selection = get_canvas_view()->get_selection_manager()->get_selected_layers();
+
+		// count how many layers we're going to be creating
+		int layers_to_create = this->layers_to_create();
 
 		///////////////////////////////////////////////////////////////////////////
 		//   C U R V E   G R A D I E N T
@@ -642,7 +647,8 @@ StateBLine_Context::run_()
 				}
 			}
 
-			if (get_layer_link_offsets_flag())
+			// only link the curve gradient's origin parameter if the option is selected and we're creating more than one layer
+			if (get_layer_link_origins_flag() && layers_to_create > 1)
 			{
 				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
 				assert(action);
@@ -650,9 +656,9 @@ StateBLine_Context::run_()
 				action->set_param("canvas",get_canvas());
 				action->set_param("canvas_interface",get_canvas_interface());
 				action->set_param("layer",layer);
-				if(!action->set_param("param",String("offset")))
+				if(!action->set_param("param",String("origin")))
 					synfig::error("LayerParamConnect didn't like \"param\"");
-				if(!action->set_param("value_node",ValueNode::Handle(value_node_offset)))
+				if(!action->set_param("value_node",ValueNode::Handle(value_node_origin)))
 					synfig::error("LayerParamConnect didn't like \"value_node\"");
 
 				if(!get_canvas_interface()->get_instance()->perform_action(action))
@@ -700,8 +706,8 @@ StateBLine_Context::run_()
 				}
 			}
 
-			// plants don't have offsets?
-			if (get_layer_link_offsets_flag())
+			// only link the plant's origin parameter if the option is selected and we're creating more than one layer
+			if (get_layer_link_origins_flag() && layers_to_create > 1)
 			{
 				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
 				assert(action);
@@ -709,9 +715,9 @@ StateBLine_Context::run_()
 				action->set_param("canvas",get_canvas());
 				action->set_param("canvas_interface",get_canvas_interface());
 				action->set_param("layer",layer);
-				if(!action->set_param("param",String("offset")))
+				if(!action->set_param("param",String("origin")))
 					synfig::error("LayerParamConnect didn't like \"param\"");
-				if(!action->set_param("value_node",ValueNode::Handle(value_node_offset)))
+				if(!action->set_param("value_node",ValueNode::Handle(value_node_origin)))
 					synfig::error("LayerParamConnect didn't like \"value_node\"");
 
 				if(!get_canvas_interface()->get_instance()->perform_action(action))
@@ -770,7 +776,8 @@ StateBLine_Context::run_()
 				}
 			}
 
-			if (get_layer_link_offsets_flag())
+			// only link the region's origin parameter if the option is selected and we're creating more than one layer
+			if (get_layer_link_origins_flag() && layers_to_create > 1)
 			{
 				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
 				assert(action);
@@ -778,9 +785,9 @@ StateBLine_Context::run_()
 				action->set_param("canvas",get_canvas());
 				action->set_param("canvas_interface",get_canvas_interface());
 				action->set_param("layer",layer);
-				if(!action->set_param("param",String("offset")))
+				if(!action->set_param("param",String("origin")))
 					synfig::error("LayerParamConnect didn't like \"param\"");
-				if(!action->set_param("value_node",ValueNode::Handle(value_node_offset)))
+				if(!action->set_param("value_node",ValueNode::Handle(value_node_origin)))
 					synfig::error("LayerParamConnect didn't like \"value_node\"");
 
 				if(!get_canvas_interface()->get_instance()->perform_action(action))
@@ -833,7 +840,8 @@ StateBLine_Context::run_()
 				}
 			}
 
-			if (get_layer_link_offsets_flag())
+			// only link the outline's origin parameter if the option is selected and we're creating more than one layer
+			if (get_layer_link_origins_flag() && layers_to_create > 1)
 			{
 				synfigapp::Action::Handle action(synfigapp::Action::create("layer_param_connect"));
 				assert(action);
@@ -841,9 +849,9 @@ StateBLine_Context::run_()
 				action->set_param("canvas",get_canvas());
 				action->set_param("canvas_interface",get_canvas_interface());
 				action->set_param("layer",layer);
-				if(!action->set_param("param",String("offset")))
+				if(!action->set_param("param",String("origin")))
 					synfig::error("LayerParamConnect didn't like \"param\"");
-				if(!action->set_param("value_node",ValueNode::Handle(value_node_offset)))
+				if(!action->set_param("value_node",ValueNode::Handle(value_node_origin)))
 					synfig::error("LayerParamConnect didn't like \"value_node\"");
 
 				if(!get_canvas_interface()->get_instance()->perform_action(action))
@@ -1306,11 +1314,7 @@ StateBLine_Context::bline_insert_vertex(synfig::ValueNode_Const::Handle value_no
 
 			bline_point.set_vertex(curve(origin));
 			bline_point.set_width((next_bline_point.get_width()-prev_bline_point.get_width())*origin+prev_bline_point.get_width());
-#ifdef ETL_FIXED_DERIVATIVE
 			bline_point.set_tangent1(deriv(origin)*std::min(1.0f-origin,origin));
-#else
-			bline_point.set_tangent1(-deriv(origin)*std::min(1.0f-origin,origin));
-#endif
 			bline_point.set_tangent2(bline_point.get_tangent1());
 			bline_point.set_split_tangent_flag(false);
 			bline_point.set_origin(origin);
