@@ -2,10 +2,11 @@
 /*!	\file state_gradient.cpp
 **	\brief Template File
 **
-**	$Id: state_gradient.cpp 1491 2008-01-25 18:11:04Z dooglus $
+**	$Id: state_gradient.cpp 2098 2008-10-14 21:00:21Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**  Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -98,7 +99,9 @@ class studio::StateGradient_Context : public sigc::trackable
 	Gtk::Table options_table;
 	Gtk::Entry entry_id;
 	Widget_Enum enum_type;
+#ifdef BLEND_METHOD_IN_TOOL_OPTIONS
 	Widget_Enum	enum_blend;
+#endif	// BLEND_METHOD_IN_TOOL_OPTIONS
 
 public:
 	synfig::String get_id()const { return entry_id.get_text(); }
@@ -107,8 +110,10 @@ public:
 	int get_type()const { return enum_type.get_value(); }
 	void set_type(int x) { return enum_type.set_value(x); }
 
+#ifdef BLEND_METHOD_IN_TOOL_OPTIONS
 	int get_blend()const { return enum_blend.get_value(); }
 	void set_blend(int x) { return enum_blend.set_value(x); }
+#endif	// BLEND_METHOD_IN_TOOL_OPTIONS
 
 	Smach::event_result event_stop_handler(const Smach::event& x);
 
@@ -180,10 +185,12 @@ StateGradient_Context::load_settings()
 	else
 		set_type(GRADIENT_INTERPOLATION_LINEAR);
 
+#ifdef BLEND_METHOD_IN_TOOL_OPTIONS
 	if(settings.get_value("gradient.blend",value))
 		set_blend(atoi(value.c_str()));
 	else
 		set_blend(Color::BLEND_COMPOSITE);
+#endif	// BLEND_METHOD_IN_TOOL_OPTIONS
 }
 
 void
@@ -191,7 +198,9 @@ StateGradient_Context::save_settings()
 {
 	settings.set_value("gradient.id",get_id().c_str());
 	settings.set_value("gradient.type",strprintf("%d",get_type()));
+#ifdef BLEND_METHOD_IN_TOOL_OPTIONS
 	settings.set_value("gradient.blend",strprintf("%d",get_blend()));
+#endif	// BLEND_METHOD_IN_TOOL_OPTIONS
 }
 
 void
@@ -255,8 +264,8 @@ StateGradient_Context::StateGradient_Context(CanvasView* canvas_view):
 {
 	egress_on_selection_change=true;
 	// Set up the tool options dialog
-	///options_table.attach(*manage(new Gtk::Label(_("Gradient Tool"))), 0, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(entry_id, 0, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(*manage(new Gtk::Label(_("Gradient Tool"))),	0, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(entry_id,										0, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
 	enum_type.set_param_desc(ParamDesc("type")
 		.set_local_name(_("Gradient Type"))
@@ -267,14 +276,18 @@ StateGradient_Context::StateGradient_Context(CanvasView* canvas_view):
 		.add_enum_value(GRADIENT_CONICAL,"conical",_("Conical"))
 		.add_enum_value(GRADIENT_SPIRAL,"spiral",_("Spiral")));
 
+#ifdef BLEND_METHOD_IN_TOOL_OPTIONS
 	enum_blend.set_param_desc(ParamDesc(Color::BLEND_COMPOSITE,"blend_method")
 		.set_local_name(_("Blend Method"))
 		.set_description(_("The blend method the gradient will use")));
+#endif	// BLEND_METHOD_IN_TOOL_OPTIONS
 
 	load_settings();
 
 	options_table.attach(enum_type, 0, 2, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+#ifdef BLEND_METHOD_IN_TOOL_OPTIONS
 	options_table.attach(enum_blend, 0, 2, 3, 4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+#endif	// BLEND_METHOD_IN_TOOL_OPTIONS
 
 	options_table.show_all();
 	refresh_tool_options();
@@ -342,6 +355,8 @@ StateGradient_Context::~StateGradient_Context()
 	// Refresh the work area
 	get_work_area()->queue_draw();
 
+	get_canvas_view()->queue_rebuild_ducks();
+
 	//get_canvas_view()->show_tables();
 
 	get_work_area()->refresh_cursor();
@@ -428,15 +443,21 @@ StateGradient_Context::make_gradient(const Point& _p1, const Point& _p2)
 		return;
 	}
 
+#ifdef BLEND_METHOD_IN_TOOL_OPTIONS
 	layer->set_param("blend_method",get_blend());
 	get_canvas_interface()->signal_layer_param_changed()(layer,"blend_method");
+#endif	// BLEND_METHOD_IN_TOOL_OPTIONS
 
 	layer->set_description(get_id());
 	get_canvas_interface()->signal_layer_new_description()(layer,layer->get_description());
 
 	egress_on_selection_change=false;
+	synfigapp::SelectionManager::LayerList layer_selection;
+	if (!getenv("SYNFIG_TOOLS_CLEAR_SELECTION"))
+		layer_selection = get_canvas_view()->get_selection_manager()->get_selected_layers();
 	get_canvas_interface()->get_selection_manager()->clear_selected_layers();
-	get_canvas_interface()->get_selection_manager()->set_selected_layer(layer);
+	layer_selection.push_back(layer);
+	get_canvas_interface()->get_selection_manager()->set_selected_layers(layer_selection);
 	egress_on_selection_change=true;
 
 	reset();
@@ -473,6 +494,7 @@ StateGradient_Context::event_mouse_click_handler(const Smach::event& x)
 
 	if(event.key==EVENT_WORKAREA_MOUSE_BUTTON_DRAG && event.button==BUTTON_LEFT)
 	{
+		if (!point2_duck) return Smach::RESULT_OK;
 		point2_duck->set_point(get_work_area()->snap_point_to_grid(event.pos));
 		get_work_area()->queue_draw();
 		return Smach::RESULT_ACCEPT;
