@@ -2,10 +2,11 @@
 /*!	\file state_width.cpp
 **	\brief Template File
 **
-**	$Id: state_width.cpp 1143 2007-11-13 09:13:07Z pabs $
+**	$Id: state_width.cpp 2098 2008-10-14 21:00:21Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**  Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -105,8 +106,6 @@ class studio::StateWidth_Context : public sigc::trackable
 	//Toolbox display
 	Gtk::Table options_table;
 
-	//Gtk::Entry		entry_id; //what to name the layer
-
 	Gtk::Adjustment	adj_delta;
 	Gtk::SpinButton	spin_delta;
 
@@ -151,7 +150,7 @@ public:
 	void save_settings();
 	void reset();
 
-};	// END of class StateGradient_Context
+};	// END of class StateWidth_Context
 
 /* === M E T H O D S ======================================================= */
 
@@ -186,11 +185,11 @@ StateWidth_Context::load_settings()
 	else
 		set_radius(15);
 
-	//defaults to true
-	if(settings.get_value("width.relative",value) && value == "0")
-		set_relative(false);
-	else
+	//defaults to false
+	if(settings.get_value("width.relative",value) && value == "1")
 		set_relative(true);
+	else
+		set_relative(false);
 }
 
 void
@@ -216,10 +215,10 @@ StateWidth_Context::StateWidth_Context(CanvasView* canvas_view):
 
 	settings(synfigapp::Main::get_selected_input_device()->settings()),
 
-	adj_delta(6,0,1,0.001,0.01),
+	adj_delta(6,0,20,0.01,0.1),
 	spin_delta(adj_delta,0.01,3),
 
-	adj_radius(0,0,1e50,1,10),
+	adj_radius(200,0,1e50,1,10),
 	spin_radius(adj_radius,1,1),
 
 	check_relative(_("Relative Growth"))
@@ -227,17 +226,16 @@ StateWidth_Context::StateWidth_Context(CanvasView* canvas_view):
 	load_settings();
 
 	// Set up the tool options dialog
-	//options_table.attach(*manage(new Gtk::Label(_("Width Tool"))), 0, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	//options_table.attach(entry_id, 0, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(*manage(new Gtk::Label(_("Width Tool"))),	0, 2, 0, 1, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
 	//expand stuff
-	options_table.attach(*manage(new Gtk::Label(_("Growth:"))), 0, 1, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_delta, 1, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(*manage(new Gtk::Label(_("Growth:"))),		0, 1, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_delta,								1, 2, 1, 2, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
-	options_table.attach(*manage(new Gtk::Label(_("Radius:"))), 0, 1, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
-	options_table.attach(spin_radius, 1, 2, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(*manage(new Gtk::Label(_("Radius:"))),		0, 1, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(spin_radius,								1, 2, 2, 3, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
-	options_table.attach(check_relative, 0, 2, 3, 4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
+	options_table.attach(check_relative,							0, 2, 3, 4, Gtk::EXPAND|Gtk::FILL, Gtk::EXPAND|Gtk::FILL, 0, 0);
 
 	options_table.show_all();
 
