@@ -2,10 +2,11 @@
 /*!	\file widget_curves.cpp
 **	\brief Template File
 **
-**	$Id: widget_curves.cpp 1334 2008-01-12 17:06:17Z dooglus $
+**	$Id: widget_curves.cpp 2098 2008-10-14 21:00:21Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**  Copyright (c) 2008 Gerco Ballintijn
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -289,6 +290,12 @@ struct studio::Widget_Curves::CurveStruct : sigc::trackable
 
 		return -channels[chan].values[time];
 	}
+
+	static bool is_not_supported(const synfigapp::ValueDesc& x)
+	{
+		return x.get_value_type() == ValueBase::TYPE_STRING
+			|| x.get_value_type() == ValueBase::TYPE_CANVAS;
+	}
 };
 
 /* === M E T H O D S ======================================================= */
@@ -365,6 +372,9 @@ Widget_Curves::set_value_descs(std::list<synfigapp::ValueDesc> value_descs)
 	std::list<synfigapp::ValueDesc>::iterator iter;
 	for(iter=value_descs.begin();iter!=value_descs.end();++iter)
 	{
+		if (CurveStruct::is_not_supported(*iter))
+	        	continue;
+
 		try {
 			curve_list_.push_back(*iter);
 			if(iter->is_value_node())
