@@ -2,7 +2,7 @@
 /*!	\file workarea.cpp
 **	\brief Template Header
 **
-**	$Id: workarea.cpp 1801 2008-02-23 01:25:23Z dooglus $
+**	$Id: workarea.cpp 2024 2008-04-20 15:35:48Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -1371,15 +1371,19 @@ WorkArea::on_drawing_area_event(GdkEvent *event)
 						// if the tangent isn't split, then split it
 						if (!((*(parent_value_node->get_link("split")))(get_time()).get(bool())))
 						{
-							get_canvas_view()->canvas_interface()->
+							if (get_canvas_view()->canvas_interface()->
 								change_value(synfigapp::ValueDesc(parent_value_node,
 																  parent_value_node->get_link_index_from_name("split")),
-											 true);
-							// rebuild the ducks from scratch, so the tangents ducks aren't connected
-							get_canvas_view()->rebuild_ducks();
+											 true))
+							{
+								// rebuild the ducks from scratch, so the tangents ducks aren't connected
+								get_canvas_view()->rebuild_ducks();
 
-							// reprocess the mouse click
-							return on_drawing_area_event(event);
+								// reprocess the mouse click
+								return on_drawing_area_event(event);
+							}
+							else
+								return true;
 						}
 					} else {
 						// I don't know how to access the vertex from the tangent duck when originally drawing the bline in the bline tool
@@ -2133,8 +2137,6 @@ WorkArea::refresh(GdkEventExpose*event)
 		drawing_frame->unset_bg(Gtk::STATE_NORMAL);
 #endif
 
-	previous_focus=get_focus_point();
-
 	return true;
 }
 
@@ -2579,20 +2581,24 @@ studio::WorkArea::zoom_out()
 void
 studio::WorkArea::zoom_fit()
 {
-	// This really doesn't zoom to fit. Bug.
-	zoom_norm();
+	float new_zoom(min(drawing_area->get_width() * zoom / w, drawing_area->get_height() * zoom / h));
+	if (zoom / new_zoom > 0.995 && new_zoom / zoom > 0.995)
+	{
+		set_zoom(prev_zoom);
+		return set_focus_point(previous_focus);
+	}
+	previous_focus = get_focus_point();
+	prev_zoom = zoom;
+	set_zoom(new_zoom);
+	set_focus_point(Point(0,0));
 }
 
 void
 studio::WorkArea::zoom_norm()
 {
-	if(zoom==1.0)
-		set_zoom(prev_zoom);
-	else
-	{
-		prev_zoom=zoom;
-		set_zoom(1.0f);
-	}
+	if (zoom == 1.0) return set_zoom(prev_zoom);
+	prev_zoom = zoom;
+	set_zoom(1.0f);
 }
 
 gboolean
