@@ -2,7 +2,7 @@
 /*!	\file action.cpp
 **	\brief Template File
 **
-**	$Id: action.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id: action.cpp 1923 2008-03-26 20:04:43Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -68,11 +68,13 @@
 #include "actions/valuedescconnect.h"
 #include "actions/valuedescdisconnect.h"
 #include "actions/valuedesclink.h"
+#include "actions/valuedescblinelink.h"
 
 #include "actions/waypointadd.h"
 #include "actions/waypointset.h"
 #include "actions/waypointsetsmart.h"
 #include "actions/waypointremove.h"
+// #include "actions/waypointsimpleadd.h"
 
 #include "actions/activepointadd.h"
 #include "actions/activepointset.h"
@@ -80,6 +82,7 @@
 #include "actions/activepointsetoff.h"
 #include "actions/activepointseton.h"
 #include "actions/activepointremove.h"
+// #include "actions/activepointsimpleadd.h"
 
 #include "actions/keyframeadd.h"
 #include "actions/keyframeset.h"
@@ -92,6 +95,9 @@
 #include "actions/timepointscopy.h"
 #include "actions/timepointsdelete.h"
 
+#include "actions/canvasdescriptionset.h"
+#include "actions/canvasidset.h"
+#include "actions/canvasnameset.h"
 #include "actions/canvasrenddescset.h"
 #include "actions/canvasadd.h"
 #include "actions/canvasremove.h"
@@ -180,11 +186,13 @@ Action::Main::Main()
 	ADD_ACTION(Action::ValueDescConnect);
 	ADD_ACTION(Action::ValueDescDisconnect);
 	ADD_ACTION(Action::ValueDescLink);
+	ADD_ACTION(Action::ValueDescBLineLink);
 
 	ADD_ACTION(Action::WaypointAdd);
 	ADD_ACTION(Action::WaypointSet);
 	ADD_ACTION(Action::WaypointSetSmart);
 	ADD_ACTION(Action::WaypointRemove);
+//	ADD_ACTION(Action::WaypointSimpleAdd);
 
 	ADD_ACTION(Action::ActivepointAdd);
 	ADD_ACTION(Action::ActivepointSet);
@@ -192,6 +200,7 @@ Action::Main::Main()
 	ADD_ACTION(Action::ActivepointSetOn);
 	ADD_ACTION(Action::ActivepointSetOff);
 	ADD_ACTION(Action::ActivepointRemove);
+//	ADD_ACTION(Action::ActivepointSimpleAdd);
 
 	ADD_ACTION(Action::KeyframeAdd);
 	ADD_ACTION(Action::KeyframeSet);
@@ -200,6 +209,9 @@ Action::Main::Main()
 	ADD_ACTION(Action::KeyframeWaypointSet);
 	ADD_ACTION(Action::KeyframeSetDelta);
 
+	ADD_ACTION(Action::CanvasDescriptionSet);
+	ADD_ACTION(Action::CanvasIdSet);
+	ADD_ACTION(Action::CanvasNameSet);
 	ADD_ACTION(Action::CanvasRendDescSet);
 	ADD_ACTION(Action::CanvasAdd);
 	ADD_ACTION(Action::CanvasRemove);
