@@ -2,10 +2,11 @@
 /*!	\file activepointset.cpp
 **	\brief Template File
 **
-**	$Id: activepointset.cpp 1143 2007-11-13 09:13:07Z pabs $
+**	$Id: activepointset.cpp 2098 2008-10-14 21:00:21Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**  Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -51,7 +52,7 @@ ACTION_SET_TASK(Action::ActivepointSet,"set");
 ACTION_SET_CATEGORY(Action::ActivepointSet,Action::CATEGORY_ACTIVEPOINT);
 ACTION_SET_PRIORITY(Action::ActivepointSet,0);
 ACTION_SET_VERSION(Action::ActivepointSet,"0.0");
-ACTION_SET_CVS_ID(Action::ActivepointSet,"$Id: activepointset.cpp 1143 2007-11-13 09:13:07Z pabs $");
+ACTION_SET_CVS_ID(Action::ActivepointSet,"$Id: activepointset.cpp 2098 2008-10-14 21:00:21Z genete $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -85,15 +86,14 @@ Action::ActivepointSet::get_param_vocab()
 bool
 Action::ActivepointSet::is_candidate(const ParamList &x)
 {
-	if(candidate_check(get_param_vocab(),x))
-	{
-		ValueDesc value_desc(x.find("value_desc")->second.get_value_desc());
-		if(!value_desc.parent_is_value_node() || !ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_parent_value_node()))
-			return false;
+	if (!candidate_check(get_param_vocab(),x))
+		return false;
 
-		return true;
-	}
-	return false;
+	ValueDesc value_desc(x.find("value_desc")->second.get_value_desc());
+
+	return (value_desc.parent_is_value_node() &&
+			// We need a dynamic list.
+			ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_parent_value_node()));
 }
 
 bool
