@@ -2,10 +2,11 @@
 /*!	\file activepointseton.cpp
 **	\brief Template File
 **
-**	$Id: activepointseton.cpp 1143 2007-11-13 09:13:07Z pabs $
+**	$Id: activepointseton.cpp 2098 2008-10-14 21:00:21Z genete $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**  Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -59,7 +60,7 @@ ACTION_SET_TASK(Action::ActivepointSetOn,"set_on");
 ACTION_SET_CATEGORY(Action::ActivepointSetOn,Action::CATEGORY_ACTIVEPOINT|Action::CATEGORY_VALUEDESC);
 ACTION_SET_PRIORITY(Action::ActivepointSetOn,-10);
 ACTION_SET_VERSION(Action::ActivepointSetOn,"0.0");
-ACTION_SET_CVS_ID(Action::ActivepointSetOn,"$Id: activepointseton.cpp 1143 2007-11-13 09:13:07Z pabs $");
+ACTION_SET_CVS_ID(Action::ActivepointSetOn,"$Id: activepointseton.cpp 2098 2008-10-14 21:00:21Z genete $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -99,22 +100,22 @@ Action::ActivepointSetOn::get_param_vocab()
 bool
 Action::ActivepointSetOn::is_candidate(const ParamList &x)
 {
-	if(candidate_check(get_param_vocab(),x))
-	{
-		ValueDesc value_desc(x.find("value_desc")->second.get_value_desc());
-		if(!value_desc.parent_is_value_node() || !ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_parent_value_node()))
-			return false;
+	if (!candidate_check(get_param_vocab(),x))
+		return false;
 
-		// We are only a candidate if this canvas is animated.
-		Canvas::Handle canvas(x.find("canvas")->second.get_canvas());
-		if(canvas->rend_desc().get_time_start()==canvas->rend_desc().get_time_end())
-			return false;
+	ValueDesc value_desc(x.find("value_desc")->second.get_value_desc());
 
-		// We need either a activepoint or a time.
-		if(x.count("activepoint") || x.count("time"))
-			return true;
-	}
-	return false;
+	if (!(value_desc.parent_is_value_node() &&
+		  // We need a dynamic list.
+		  ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_parent_value_node())))
+		return false;
+
+	Canvas::Handle canvas(x.find("canvas")->second.get_canvas());
+
+	// We are only a candidate if this canvas is animated.
+	return (canvas->rend_desc().get_time_start() != canvas->rend_desc().get_time_end() &&
+			// We need either an activepoint or a time.
+			(x.count("activepoint") || x.count("time")));
 }
 
 bool
