@@ -2,7 +2,7 @@
 /*!	\file keyframeremove.cpp
 **	\brief Template File
 **
-**	$Id: keyframeremove.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: keyframeremove.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -36,6 +36,8 @@
 #include "activepointremove.h"
 #include "waypointremove.h"
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -48,12 +50,12 @@ using namespace Action;
 
 ACTION_INIT(Action::KeyframeRemove);
 ACTION_SET_NAME(Action::KeyframeRemove,"keyframe_remove");
-ACTION_SET_LOCAL_NAME(Action::KeyframeRemove,"Remove Keyframe");
+ACTION_SET_LOCAL_NAME(Action::KeyframeRemove,N_("Remove Keyframe"));
 ACTION_SET_TASK(Action::KeyframeRemove,"remove");
 ACTION_SET_CATEGORY(Action::KeyframeRemove,Action::CATEGORY_KEYFRAME);
 ACTION_SET_PRIORITY(Action::KeyframeRemove,0);
 ACTION_SET_VERSION(Action::KeyframeRemove,"0.0");
-ACTION_SET_CVS_ID(Action::KeyframeRemove,"$Id: keyframeremove.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::KeyframeRemove,"$Id: keyframeremove.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
