@@ -2,7 +2,7 @@
 /*!	\file timepointscopy.cpp
 **	\brief Copy the Time Points File
 **
-**	$Id: timepointscopy.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: timepointscopy.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2004 Adrian Bentley
@@ -41,6 +41,8 @@
 
 #include <typeinfo>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -53,12 +55,12 @@ using namespace Action;
 
 ACTION_INIT(Action::TimepointsCopy);
 ACTION_SET_NAME(Action::TimepointsCopy,"timepoint_copy");
-ACTION_SET_LOCAL_NAME(Action::TimepointsCopy,"Copy Time Points");
+ACTION_SET_LOCAL_NAME(Action::TimepointsCopy,N_("Copy Time Points"));
 ACTION_SET_TASK(Action::TimepointsCopy,"copy");
 ACTION_SET_CATEGORY(Action::TimepointsCopy,Action::CATEGORY_WAYPOINT|Action::CATEGORY_ACTIVEPOINT);
 ACTION_SET_PRIORITY(Action::TimepointsCopy,0);
 ACTION_SET_VERSION(Action::TimepointsCopy,"0.0");
-ACTION_SET_CVS_ID(Action::TimepointsCopy,"$Id: timepointscopy.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::TimepointsCopy,"$Id: timepointscopy.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
