@@ -2,7 +2,7 @@
 /*!	\file timepointsdelete.cpp
 **	\brief Delete the Time Points File
 **
-**	$Id: timepointsdelete.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: timepointsdelete.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2004 Adrian Bentley
@@ -41,6 +41,8 @@
 
 #include <typeinfo>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -53,12 +55,12 @@ using namespace Action;
 
 ACTION_INIT(Action::TimepointsDelete);
 ACTION_SET_NAME(Action::TimepointsDelete,"timepoint_delete");
-ACTION_SET_LOCAL_NAME(Action::TimepointsDelete,"Delete Time Points");
+ACTION_SET_LOCAL_NAME(Action::TimepointsDelete,N_("Delete Time Points"));
 ACTION_SET_TASK(Action::TimepointsDelete,"delete");
 ACTION_SET_CATEGORY(Action::TimepointsDelete,Action::CATEGORY_WAYPOINT|Action::CATEGORY_ACTIVEPOINT);
 ACTION_SET_PRIORITY(Action::TimepointsDelete,0);
 ACTION_SET_VERSION(Action::TimepointsDelete,"0.0");
-ACTION_SET_CVS_ID(Action::TimepointsDelete,"$Id: timepointsdelete.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::TimepointsDelete,"$Id: timepointsdelete.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
