@@ -2,10 +2,11 @@
 /*!	\file valuedescexport.cpp
 **	\brief Template File
 **
-**	$Id: valuedescexport.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuedescexport.cpp 1643 2008-02-09 19:12:18Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
+**	Copyright (c) 2008 Chris Moore
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -38,6 +39,8 @@
 #include <synfigapp/canvasinterface.h>
 #include <synfig/valuenode_const.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -48,14 +51,14 @@ using namespace Action;
 
 /* === M A C R O S ========================================================= */
 
-ACTION_INIT(Action::ValueDescExport);
+ACTION_INIT_NO_GET_LOCAL_NAME(Action::ValueDescExport);
 ACTION_SET_NAME(Action::ValueDescExport,"value_desc_export");
-ACTION_SET_LOCAL_NAME(Action::ValueDescExport,"Export");
+ACTION_SET_LOCAL_NAME(Action::ValueDescExport,N_("Export"));
 ACTION_SET_TASK(Action::ValueDescExport,"export");
 ACTION_SET_CATEGORY(Action::ValueDescExport,Action::CATEGORY_VALUEDESC);
 ACTION_SET_PRIORITY(Action::ValueDescExport,0);
 ACTION_SET_VERSION(Action::ValueDescExport,"0.0");
-ACTION_SET_CVS_ID(Action::ValueDescExport,"$Id: valuedescexport.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueDescExport,"$Id: valuedescexport.cpp 1643 2008-02-09 19:12:18Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -67,6 +70,15 @@ Action::ValueDescExport::ValueDescExport()
 {
 }
 
+synfig::String
+Action::ValueDescExport::get_local_name()const
+{
+	// TRANSLATORS: This is used in the 'history' dialog when a ValueNode is exported.  The first %s is what is exported, the 2nd is the name it is given.
+	return strprintf(_("Export '%s' as '%s'"),
+					 value_desc.get_description(false).c_str(),
+					 name.c_str());
+}
+
 Action::ParamVocab
 Action::ValueDescExport::get_param_vocab()
 {
