@@ -2,7 +2,7 @@
 /*!	\file valuenodeconstset.cpp
 **	\brief Template File
 **
-**	$Id: valuenodeconstset.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuenodeconstset.cpp 1143 2007-11-13 09:13:07Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "valuenodeconstset.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ValueNodeConstSet);
 ACTION_SET_NAME(Action::ValueNodeConstSet,"value_node_const_set");
-ACTION_SET_LOCAL_NAME(Action::ValueNodeConstSet,_("Set ValueNode_Const"));
+ACTION_SET_LOCAL_NAME(Action::ValueNodeConstSet,N_("Set ValueNode_Const"));
 ACTION_SET_TASK(Action::ValueNodeConstSet,"set");
 ACTION_SET_CATEGORY(Action::ValueNodeConstSet,Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueNodeConstSet,0);
 ACTION_SET_VERSION(Action::ValueNodeConstSet,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeConstSet,"$Id: valuenodeconstset.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueNodeConstSet,"$Id: valuenodeconstset.cpp 1143 2007-11-13 09:13:07Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
