@@ -2,7 +2,7 @@
 /*!	\file valuenodedynamiclistinsertsmart.cpp
 **	\brief Template File
 **
-**	$Id: valuenodedynamiclistinsertsmart.cpp 1143 2007-11-13 09:13:07Z pabs $
+**	$Id: valuenodedynamiclistinsertsmart.cpp 1864 2008-03-06 20:37:48Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -53,7 +53,7 @@ ACTION_SET_TASK(Action::ValueNodeDynamicListInsertSmart,"insert");
 ACTION_SET_CATEGORY(Action::ValueNodeDynamicListInsertSmart,Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::ValueNodeDynamicListInsertSmart,-20);
 ACTION_SET_VERSION(Action::ValueNodeDynamicListInsertSmart,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeDynamicListInsertSmart,"$Id: valuenodedynamiclistinsertsmart.cpp 1143 2007-11-13 09:13:07Z pabs $");
+ACTION_SET_CVS_ID(Action::ValueNodeDynamicListInsertSmart,"$Id: valuenodedynamiclistinsertsmart.cpp 1864 2008-03-06 20:37:48Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -92,15 +92,14 @@ Action::ValueNodeDynamicListInsertSmart::get_param_vocab()
 bool
 Action::ValueNodeDynamicListInsertSmart::is_candidate(const ParamList &x)
 {
-	if(candidate_check(get_param_vocab(),x))
-	{
-		ValueDesc value_desc(x.find("value_desc")->second.get_value_desc());
-		if(!value_desc.parent_is_value_node() || !ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_parent_value_node()))
-			return false;
+	if (!candidate_check(get_param_vocab(),x))
+		return false;
 
-		return true;
-	}
-	return false;
+	ValueDesc value_desc(x.find("value_desc")->second.get_value_desc());
+
+	return (value_desc.parent_is_value_node() &&
+			// We need a dynamic list.
+			ValueNode_DynamicList::Handle::cast_dynamic(value_desc.get_parent_value_node()));
 }
 
 bool
