@@ -2,7 +2,7 @@
 /*!	\file valuenodereplace.cpp
 **	\brief Template File
 **
-**	$Id: valuenodereplace.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: valuenodereplace.cpp 1809 2008-02-24 05:16:03Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -32,6 +32,8 @@
 #include "valuenodereplace.h"
 #include <synfigapp/canvasinterface.h>
 
+#include <synfigapp/general.h>
+
 #endif
 
 using namespace std;
@@ -44,12 +46,12 @@ using namespace Action;
 
 ACTION_INIT(Action::ValueNodeReplace);
 ACTION_SET_NAME(Action::ValueNodeReplace,"value_node_replace");
-ACTION_SET_LOCAL_NAME(Action::ValueNodeReplace,"Replace ValueNode");
+ACTION_SET_LOCAL_NAME(Action::ValueNodeReplace,N_("Replace ValueNode"));
 ACTION_SET_TASK(Action::ValueNodeReplace,"replace");
 ACTION_SET_CATEGORY(Action::ValueNodeReplace,Action::CATEGORY_VALUENODE|Action::CATEGORY_DRAG);
 ACTION_SET_PRIORITY(Action::ValueNodeReplace,0);
 ACTION_SET_VERSION(Action::ValueNodeReplace,"0.0");
-ACTION_SET_CVS_ID(Action::ValueNodeReplace,"$Id: valuenodereplace.cpp 336 2007-03-16 00:39:42Z dooglus $");
+ACTION_SET_CVS_ID(Action::ValueNodeReplace,"$Id: valuenodereplace.cpp 1809 2008-02-24 05:16:03Z pabs $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -57,11 +59,11 @@ ACTION_SET_CVS_ID(Action::ValueNodeReplace,"$Id: valuenodereplace.cpp 336 2007-0
 
 void swap_guid(const ValueNode::Handle& a,const ValueNode::Handle& b)
 {
-	GUID old_a(a->get_guid());
-	a->set_guid(GUID());
+	synfig::GUID old_a(a->get_guid());
+	a->set_guid(synfig::GUID());
 
-	GUID old_b(b->get_guid());
-	b->set_guid(GUID());
+	synfig::GUID old_b(b->get_guid());
+	b->set_guid(synfig::GUID());
 
 	a->set_guid(old_b);
 	b->set_guid(old_a);
