@@ -2,7 +2,7 @@
 /*!	\file waypointsetsmart.cpp
 **	\brief Template File
 **
-**	$Id: waypointsetsmart.cpp 1834 2008-03-02 15:54:10Z dooglus $
+**	$Id: waypointsetsmart.cpp 1864 2008-03-06 20:37:48Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -61,7 +61,7 @@ ACTION_SET_TASK(Action::WaypointSetSmart,"set");
 ACTION_SET_CATEGORY(Action::WaypointSetSmart,Action::CATEGORY_WAYPOINT|Action::CATEGORY_VALUEDESC|Action::CATEGORY_VALUENODE);
 ACTION_SET_PRIORITY(Action::WaypointSetSmart,0);
 ACTION_SET_VERSION(Action::WaypointSetSmart,"0.0");
-ACTION_SET_CVS_ID(Action::WaypointSetSmart,"$Id: waypointsetsmart.cpp 1834 2008-03-02 15:54:10Z dooglus $");
+ACTION_SET_CVS_ID(Action::WaypointSetSmart,"$Id: waypointsetsmart.cpp 1864 2008-03-06 20:37:48Z dooglus $");
 
 /* === G L O B A L S ======================================================= */
 
@@ -108,16 +108,11 @@ Action::WaypointSetSmart::get_param_vocab()
 bool
 Action::WaypointSetSmart::is_candidate(const ParamList &x)
 {
-	if(candidate_check(get_param_vocab(),x))
-	{
-		if(!ValueNode_Animated::Handle::cast_dynamic(x.find("value_node")->second.get_value_node()))
-			return false;
-		// We need either a waypoint or a time.
-		if(x.count("waypoint") || x.count("time"))
-			return true;
-		return false;
-	}
-	return false;
+	return (candidate_check(get_param_vocab(),x) &&
+			// We need an animated valuenode.
+			ValueNode_Animated::Handle::cast_dynamic(x.find("value_node")->second.get_value_node()) &&
+			// We need either a waypoint or a time.
+			(x.count("waypoint") || x.count("time")));
 }
 
 bool
