@@ -2,7 +2,7 @@
 /*!	\file synfigapp/instance.cpp
 **	\brief Instance
 **
-**	$Id: instance.cpp 1643 2008-02-09 19:12:18Z dooglus $
+**	$Id: instance.cpp 1939 2008-03-30 09:15:54Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -38,6 +38,9 @@
 #include <synfig/valuenode_composite.h>
 #include <synfig/valuenode_radialcomposite.h>
 #include <synfig/valuenode_reference.h>
+#include <synfig/valuenode_blinecalctangent.h>
+#include <synfig/valuenode_blinecalcvertex.h>
+#include <synfig/valuenode_blinecalcwidth.h>
 #include <map>
 
 #include "general.h"
@@ -67,6 +70,9 @@ synfigapp::is_editable(synfig::ValueNode::Handle value_node)
 		|| ValueNode_Composite::Handle::cast_dynamic(value_node)
 		|| ValueNode_RadialComposite::Handle::cast_dynamic(value_node)
 		|| ValueNode_Reference::Handle::cast_dynamic(value_node)
+		|| ValueNode_BLineCalcVertex::Handle::cast_dynamic(value_node)
+		|| ValueNode_BLineCalcTangent::Handle::cast_dynamic(value_node)
+		|| ValueNode_BLineCalcWidth::Handle::cast_dynamic(value_node)
 	)
 		return true;
 	return false;
