@@ -2,7 +2,7 @@
 /*!	\file settings.cpp
 **	\brief Template File
 **
-**	$Id: settings.cpp 1460 2008-01-25 10:20:02Z pabs $
+**	$Id: settings.cpp 1977 2008-04-07 20:15:28Z dooglus $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -199,7 +199,7 @@ Settings::save_to_file(const synfig::String& filename)const
 			{
 				if(!file)return false;
 				String ret = get_value(*iter);
-				if (ret != String()) file<<*iter<<'='<<ret<<endl;
+				if (ret != String()) file<<*iter<<'='<<(ret == "none" ? "normal" : ret)<<endl;
 			}
 		}
 
