@@ -1,8 +1,8 @@
 /* === S Y N F I G ========================================================= */
-/*!	\file synfigstudio/src/template.cpp
+/*!	\file template.cpp
 **	\brief Template File
 **
-**	$Id: template.cpp 336 2007-03-16 00:39:42Z dooglus $
+**	$Id: template.cpp 1543 2008-02-01 09:37:47Z pabs $
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
@@ -39,7 +39,7 @@
 
 using namespace std;
 using namespace etl;
-using namespace synfig;
+using namespace studio;
 
 /* === M A C R O S ========================================================= */
 
